@@ -1,7 +1,7 @@
 package Display::Resolution;
 
-our $DATE = '2018-04-26'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2019-07-02'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use strict;
 use warnings;
@@ -28,10 +28,22 @@ our %res_sizes = (
     'CGA1'      => '320x200',
     'QVGA'      => '320x240', # one quarter VGA
 
+    'NTSC VCD'  => '352x240', # video cd
+    'PAL VCD'   => '352x288',
+    'SECAM VCD' => '352x288',
+
     'WQVGA'     => '400x240', # XXX there are actually variants of WQVGA, apple's ipod nano 7G's WQVGA is 432x240, etc.
     'qSVGA'     => '400x300', # quarter SVGA
 
     'HVGA'      => '480x320', # half VGA. XXX there are actually variants of HVGA, e.g. 480x270, 640x240, ...
+    'NTSC SVCD' => '480x480', # super video cd
+    'PAL SVCD'  => '480x576',
+    'SECAM SVCD'=> '480x576',
+
+    'KVCDx3 480p'  => '528x480',
+    'KVCDx3 576p'  => '528x576',
+    'KVCDx3A 480p' => '544x480',
+    'KVCDx3A 576p' => '544x576',
 
     'CGA2'      => '640x200',
     'EGA'       => '640x350',
@@ -45,7 +57,7 @@ our %res_sizes = (
 
     'WGA'       => '768x480',
     'WVGA'      => '768x480',
-    '576p'      => '720x576',
+    '576p'      => '720x576', # D1, dvd
 
     'SVGA'      => '800x600',
     'UVGA'      => '800x600',
@@ -97,7 +109,7 @@ our %res_sizes = (
     'QUXGA'     => '3200x2400',
 
     'UW4K'      => '3840x1600',
-    '2160p'     => '3840x2160',
+    '2160p'     => '3840x2160', # blu-ray
     '4K'        => '3840x2160',
     '4K UHD'    => '3840x2160',
     '4K UHD-1'  => '3840x2160',
@@ -333,7 +345,7 @@ Display::Resolution - Convert between display resolution size (e.g. 1280x720) an
 
 =head1 VERSION
 
-This document describes version 0.004 of Display::Resolution (from Perl distribution Display-Resolution), released on 2018-04-26.
+This document describes version 0.005 of Display::Resolution (from Perl distribution Display-Resolution), released on 2019-07-02.
 
 =head1 FUNCTIONS
 
@@ -393,6 +405,7 @@ When set to true, an arrayref will be returned instead of string.
 Return value:  (str|array[str])
 
 
+
 =head2 get_display_resolution_size
 
 Usage:
@@ -430,6 +443,7 @@ Arguments ('*' denotes required arguments):
 Return value:  (str)
 
 
+
 =head2 list_display_resolution_names
 
 Usage:
@@ -450,98 +464,108 @@ Result:
    200,
    "OK",
    {
-     "1080p"      => "1920x1080",
-     "1440p"      => "2560x1440",
-     "16K"        => "15360x8640",
-     "16K UHD"    => "15360x8640",
-     "2160p"      => "3840x2160",
-     "4320p"      => "7680x4320",
-     "480p"       => "720x480",
-     "4K"         => "3840x2160",
-     "4K UHD"     => "3840x2160",
-     "4K UHD-1"   => "3840x2160",
-     "576p"       => "720x576",
-     "5K"         => "5120x2880",
-     "720p"       => "1280x720",
-     "8640p"      => "15360x8640",
-     "8K"         => "7680x4320",
-     "8K UHD"     => "7680x4320",
-     "8K UHD-2"   => "7680x4320",
-     "CGA1"       => "320x200",
-     "CGA2"       => "640x200",
-     "Cinema 16K" => "16384x8640",
-     "Cinema 2K"  => "2048x1080",
-     "Cinema 4K"  => "4096x2160",
-     "Cinema 8K"  => "8192x4320",
-     "DCI 16K"    => "16384x8640",
-     "DCI 2K"     => "2048x1080",
-     "DCI 4K"     => "4096x2160",
-     "DCI 8K"     => "8192x4320",
-     "DGA"        => "960x640",
-     "DVGA"       => "960x640",
-     "EGA"        => "640x350",
-     "FHD"        => "1920x1080",
-     "Full HD"    => "1920x1080",
-     "FWVGA"      => "854x480",
-     "HD"         => "1280x720",
-     "HD+"        => "1600x900",
-     "HGC"        => "720x348",
-     "HQVGA"      => "240x160",
-     "HSXGA"      => "5120x4096",
-     "HUXGA"      => "6400x4800",
-     "HVGA"       => "480x320",
-     "HXGA"       => "4096x3072",
-     "MCGA"       => "640x480",
-     "MDA"        => "720x350",
-     "qHD"        => "960x540",
-     "QHD"        => "2560x1440",
-     "QHD+"       => "3200x1800",
-     "QQVGA"      => "160x120",
-     "qqVGA"      => "160x120",
-     "qSVGA"      => "400x300",
-     "QSXGA+"     => "2800x2100",
-     "QUXGA"      => "3200x2400",
-     "QVGA"       => "320x240",
-     "SD"         => "640x480",
-     "SVGA"       => "800x600",
-     "SXGA"       => "1280x1024",
-     "True 16K"   => "16384x8640",
-     "True 4K"    => "4096x2160",
-     "True 8K"    => "8192x4320",
-     "UHD 16K"    => "15360x8640",
-     "UHD 4K"     => "3840x2160",
-     "UHD 8K"     => "7680x4320",
-     "UHD+"       => "5120x2880",
-     "UHD-1"      => "3840x2160",
-     "UHD-2"      => "7680x4320",
-     "UHDTV-1"    => "3840x2160",
-     "UHDTV-2"    => "7680x4320",
-     "UVGA"       => "800x600",
-     "UW10K"      => "10240x4320",
-     "UW4K"       => "3840x1600",
-     "UW5K"       => "5120x2160",
-     "UWQHD"      => "3440x1440",
-     "UXGA"       => "1600x1200",
-     "VGA"        => "640x480",
-     "WGA"        => "768x480",
-     "WHSXGA"     => "6400x4096",
-     "WHUXGA"     => "7680x4800",
-     "WHXGA"      => "5120x3200",
-     "WQHD"       => "2560x1440",
-     "WQSXGA"     => "3200x2048",
-     "WQUXGA"     => "3840x2400",
-     "WQVGA"      => "400x240",
-     "WQXGA"      => "2560x1600",
-     "WQXGA+"     => "3200x1800",
-     "WSVGA"      => "1024x600",
-     "WUXGA"      => "1920x1200",
-     "WVGA"       => "768x480",
-     "WXGA 16:10" => "1280x800",
-     "WXGA 16:9"  => "1280x720",
-     "WXGA 5:3"   => "1280x768",
-     "WXGA+"      => "1440x900",
-     "XGA"        => "1024x768",
-     "XGA+"       => "1152x864",
+     "1080p"        => "1920x1080",
+     "1440p"        => "2560x1440",
+     "16K"          => "15360x8640",
+     "16K UHD"      => "15360x8640",
+     "2160p"        => "3840x2160",
+     "4320p"        => "7680x4320",
+     "480p"         => "720x480",
+     "4K"           => "3840x2160",
+     "4K UHD"       => "3840x2160",
+     "4K UHD-1"     => "3840x2160",
+     "576p"         => "720x576",
+     "5K"           => "5120x2880",
+     "720p"         => "1280x720",
+     "8640p"        => "15360x8640",
+     "8K"           => "7680x4320",
+     "8K UHD"       => "7680x4320",
+     "8K UHD-2"     => "7680x4320",
+     "CGA1"         => "320x200",
+     "CGA2"         => "640x200",
+     "Cinema 16K"   => "16384x8640",
+     "Cinema 2K"    => "2048x1080",
+     "Cinema 4K"    => "4096x2160",
+     "Cinema 8K"    => "8192x4320",
+     "DCI 16K"      => "16384x8640",
+     "DCI 2K"       => "2048x1080",
+     "DCI 4K"       => "4096x2160",
+     "DCI 8K"       => "8192x4320",
+     "DGA"          => "960x640",
+     "DVGA"         => "960x640",
+     "EGA"          => "640x350",
+     "FHD"          => "1920x1080",
+     "Full HD"      => "1920x1080",
+     "FWVGA"        => "854x480",
+     "HD"           => "1280x720",
+     "HD+"          => "1600x900",
+     "HGC"          => "720x348",
+     "HQVGA"        => "240x160",
+     "HSXGA"        => "5120x4096",
+     "HUXGA"        => "6400x4800",
+     "HVGA"         => "480x320",
+     "HXGA"         => "4096x3072",
+     "KVCDx3 480p"  => "528x480",
+     "KVCDx3 576p"  => "528x576",
+     "KVCDx3A 480p" => "544x480",
+     "KVCDx3A 576p" => "544x576",
+     "MCGA"         => "640x480",
+     "MDA"          => "720x350",
+     "NTSC SVCD"    => "480x480",
+     "NTSC VCD"     => "352x240",
+     "PAL SVCD"     => "480x576",
+     "PAL VCD"      => "352x288",
+     "qHD"          => "960x540",
+     "QHD"          => "2560x1440",
+     "QHD+"         => "3200x1800",
+     "qqVGA"        => "160x120",
+     "QQVGA"        => "160x120",
+     "qSVGA"        => "400x300",
+     "QSXGA+"       => "2800x2100",
+     "QUXGA"        => "3200x2400",
+     "QVGA"         => "320x240",
+     "SD"           => "640x480",
+     "SECAM SVCD"   => "480x576",
+     "SECAM VCD"    => "352x288",
+     "SVGA"         => "800x600",
+     "SXGA"         => "1280x1024",
+     "True 16K"     => "16384x8640",
+     "True 4K"      => "4096x2160",
+     "True 8K"      => "8192x4320",
+     "UHD 16K"      => "15360x8640",
+     "UHD 4K"       => "3840x2160",
+     "UHD 8K"       => "7680x4320",
+     "UHD+"         => "5120x2880",
+     "UHD-1"        => "3840x2160",
+     "UHD-2"        => "7680x4320",
+     "UHDTV-1"      => "3840x2160",
+     "UHDTV-2"      => "7680x4320",
+     "UVGA"         => "800x600",
+     "UW10K"        => "10240x4320",
+     "UW4K"         => "3840x1600",
+     "UW5K"         => "5120x2160",
+     "UWQHD"        => "3440x1440",
+     "UXGA"         => "1600x1200",
+     "VGA"          => "640x480",
+     "WGA"          => "768x480",
+     "WHSXGA"       => "6400x4096",
+     "WHUXGA"       => "7680x4800",
+     "WHXGA"        => "5120x3200",
+     "WQHD"         => "2560x1440",
+     "WQSXGA"       => "3200x2048",
+     "WQUXGA"       => "3840x2400",
+     "WQVGA"        => "400x240",
+     "WQXGA"        => "2560x1600",
+     "WQXGA+"       => "3200x1800",
+     "WSVGA"        => "1024x600",
+     "WUXGA"        => "1920x1200",
+     "WVGA"         => "768x480",
+     "WXGA 16:10"   => "1280x800",
+     "WXGA 16:9"    => "1280x720",
+     "WXGA 5:3"     => "1280x768",
+     "WXGA+"        => "1440x900",
+     "XGA"          => "1024x768",
+     "XGA+"         => "1152x864",
    },
    {},
  ]
@@ -582,7 +606,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2018, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
